pub async fn validate_profile_by_url(
args: FHIRProfileArguments<impl CanonicalResolver>,
canonical_url: &str,
value: &dyn MetaValue,
) -> Result<OperationOutcome, OperationOutcomeError>Expand description
Validates a value against the profile identified by its canonical URL.
Errors
Returns [OperationOutcomeError] if resolving the profile fails, if the
resolved resource is not a supported profile, or if profile validation fails.